# vplexapi
This is a python library which lets you 
manage Dell EMC VPLEX.


## Support

Vplexapi is supported by Dell EMC and is provided under the terms of the license attached to the source code.
For any setup, configuration issues, questions or feedback, join the [Dell EMC Automation community](https://www.dell.com/community/Automation/bd-p/Automation).
For any Dell EMC storage issues, please contact Dell support at: https://www.dell.com/support.
For clarity, Dell EMC does not provide support for any source code modifications.

